@@ -1,9 +1,10 @@
 #
-# $Id: String.pm,v 0.04 2004/01/02 14:57:27 st.schubiger Exp $
+# $Id: String.pm,v 0.05 2004/01/02 19:45:37 st.schubiger Exp $
 
 package Convert::ASCII::String;
 
-use strict;
+use strict; 
+no strict 'refs';
 use warnings;
 
 use Carp;
@@ -16,7 +17,7 @@ our (@EXPORT_OK, %EXPORT_TAGS, @subs, $VERSION);
 @EXPORT_OK = @subs;
 %EXPORT_TAGS = ( 'all' => [ @subs ] );
 
-$VERSION = '0.04';
+$VERSION = '0.05';
 
 =head1 NAME
 
@@ -90,11 +91,11 @@ Beware, second option will not allow back converting from ASCII.
 
 =over 4
 
-=item (0)
+=item (1)
 
 Success.
 
-=item (1)
+=item (-1)
 
 No scalar reference provided.
 
@@ -104,13 +105,13 @@ No scalar reference provided.
 
 sub string2ascii {
     my ($data_ref, $sep) = @_;
-    no strict 'refs'; $sep ||= ${__PACKAGE__.'::Sep'} || '';
-    return 1 unless ref $data_ref eq 'SCALAR';
+    $sep ||= ${__PACKAGE__.'::sep'} || '';
+    return -1 unless ref $data_ref eq 'SCALAR';
 
     my @ascii = unpack 'C*', $$data_ref;
     $$data_ref = join $sep, @ascii;
 
-    0;
+    return 1;
 }
 
 =head2 ascii2string ( \$data, $separator )
@@ -123,15 +124,15 @@ And vice versa.
 
 =over 4
 
-=item (0)
+=item (1)
 
 Success.
 
-=item (1)
+=item (-1)
 
 No scalar reference or separator provided.
 
-=item (2)
+=item (-2)
 
 Separator mismatch.
 
@@ -141,15 +142,15 @@ Separator mismatch.
 
 sub ascii2string {
     my ($data_ref, $sep) = @_;
-    no strict 'refs'; $sep ||= ${__PACKAGE__.'::Sep'};
-    return 1 unless ref $data_ref eq 'SCALAR' && $sep;
+    $sep ||= ${__PACKAGE__.'::sep'};
+    return -1 unless ref $data_ref eq 'SCALAR' && $sep;
     $sep = quotemeta $sep;
-    return 2 if $$data_ref !~ /$sep/i;
+    return -2 if $$data_ref !~ /$sep/i;
 
     my @ascii = split $sep, $$data_ref;
     $$data_ref = pack 'C*', @ascii;
 
-    0;
+    return 1;
 }
 
 1;
@@ -159,17 +160,31 @@ __END__
 
 The separator may alternatively be set by
 
- $Convert::ASCII::String::Sep = '.';
+ $Convert::ASCII::String::sep = '.';
 
 Function delivery becomes then superfluous.
 
-=head1 EXPORT
+=head1 EXPORTABLE
 
-C<string2ascii()> and C<ascii2string()> upon request.
+=over 4
+
+=item *
+
+C<string2ascii()>
+
+C<ascii2string()>
+
+=back
 
 =head2 TAGS
 
-:all - C<*()>
+=over 4
+
+=item :all 
+
+C<*()>
+
+=back
 
 =head1 SEE ALSO
 
